#[non_exhaustive]pub enum MessageType {
ItemStateEvent(StateUpdatedEvent),
ItemStateChangedEvent(StateChangedEvent),
GroupItemStateChangedEvent(StateChangedEvent),
ItemStateUpdatedEvent(StateUpdatedEvent),
ItemStatePredictedEvent(StatePredictedEvent),
GroupStateUpdatedEvent(StateUpdatedEvent),
ItemCommandEvent(StateUpdatedEvent),
RuleStatusInfoEvent(StatusInfoEvent),
ThingStatusInfoEvent(StatusInfoEvent),
ThingStatusInfoChangedEvent([StatusInfoEvent; 2]),
ChannelTriggeredEvent(ChannelTriggeredEvent),
Unknown,
}Expand description
Event type of a Message.
See https://www.openhab.org/docs/developer/utils/events.html#the-core-events.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ItemStateEvent(StateUpdatedEvent)
The state of an item is updated.
ItemStateChangedEvent(StateChangedEvent)
The state of an item has changed.
GroupItemStateChangedEvent(StateChangedEvent)
The state of a group item has changed through a member.
ItemStateUpdatedEvent(StateUpdatedEvent)
Description not present in the openHAB documentation.
ItemStatePredictedEvent(StatePredictedEvent)
The state of an item predicted to be updated.
GroupStateUpdatedEvent(StateUpdatedEvent)
Description not present in the openHAB documentation.
ItemCommandEvent(StateUpdatedEvent)
A command is sent to an item via a channel.
RuleStatusInfoEvent(StatusInfoEvent)
Description not present in the openHAB documentation.
ThingStatusInfoEvent(StatusInfoEvent)
The status of a thing is updated.
ThingStatusInfoChangedEvent([StatusInfoEvent; 2])
The status of a thing changed.
ChannelTriggeredEvent(ChannelTriggeredEvent)
A channel has been triggered.
Unknown
Unknown/not implemented