pub struct Topic {
pub namespace: String,
pub entity_type: String,
pub entity: String,
pub sub_entity: Option<String>,
pub action: String,
}Expand description
A topic clearly defines the target of the event and its structure is similar to a REST URI, except the last part, the action.
See https://www.openhab.org/docs/developer/utils/events.html#the-core-events.
Fields
namespace: Stringentity_type: Stringentity: Stringsub_entity: Option<String>GroupItemStateChangedEvent has an additional topic part
action: StringTrait Implementations
Sourceimpl<'de> Deserialize<'de> for Topic
impl<'de> Deserialize<'de> for Topic
Sourcefn deserialize<__D>(deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl StructuralPartialEq for Topic