MockTransformationsApi

Struct MockTransformationsApi 

pub struct MockTransformationsApi { /* private fields */ }

Implementations

Source

impl MockTransformationsApi

pub fn checkpoint(&mut self)

Validate that all current expectations for all methods have been satisfied, and discard them.

pub fn new() -> MockTransformationsApi

Create a new mock object with no expectations.

This method will not be generated if the real struct already has a new method. However, it will be generated if the struct implements a trait with a new method. The trait’s new method can still be called like <MockX as TraitY>::new

Source

impl MockTransformationsApi

pub fn expect_delete_transformation(&mut self) -> &mut Expectation

Create an Expectation for mocking the delete_transformation method

pub fn expect_get_transformation(&mut self) -> &mut Expectation

Create an Expectation for mocking the get_transformation method

pub fn expect_get_transformation_services(&mut self) -> &mut Expectation

Create an Expectation for mocking the get_transformation_services method

pub fn expect_get_transformations(&mut self) -> &mut Expectation

Create an Expectation for mocking the get_transformations method

pub fn expect_put_transformation(&mut self) -> &mut Expectation

Create an Expectation for mocking the put_transformation method